@@ -478,8 +478,8 @@ class ExecutionServer(BaseServer):
         for uuid in data:
             if uuid in self.active_jobs or uuid in self.queued_jobs:
                 continue
-            #if len(self.job_queue) > self.reservation_check_interval * 20:
-            #    break
+            if len(self.job_queue) > self.reservation_check_interval * 20:
+                break
             kwargs_raw = {}
             reserved_arguments = {}
             # Load attributes into dicts for use by the system or custom functions.
@@ -554,14 +554,13 @@ class ExecutionServer(BaseServer):
     def executeJobs(self, data=None):
         while len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
             job = self.job_queue.pop(0)
+            
             exposed_function = job["exposed_function"]
             kwargs = job["kwargs"]
             function_name = job["function_name"]
             uuid = job["uuid"]
             del self.queued_jobs[uuid]
-            # Call the function.
-            LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
-            # Schedule the next request.
+            LOGGER.critical("Calling %s with args %s" % (function_name, kwargs))
             self._callExposedFunction(
                 exposed_function["function"],
                 exposed_function["interval"], 
